summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H
diff options
context:
space:
mode:
authorPrem Shanker Jha <premjha2@in.ibm.com>2017-11-14 04:41:21 -0600
committerDaniel M. Crowell <dcrowell@us.ibm.com>2018-03-07 21:53:39 -0500
commit2e0c75fb9d8c92e3145bc61a9dcc658399a13c9f (patch)
treed1af6941343d6dd874adc1cd6f145308a3671077 /src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H
parent3afac7911fa47864afb15b68a1a7b76b948ca54b (diff)
downloadtalos-hostboot-2e0c75fb9d8c92e3145bc61a9dcc658399a13c9f.tar.gz
talos-hostboot-2e0c75fb9d8c92e3145bc61a9dcc658399a13c9f.zip
PM: Added support for HWP p9_pm_callout.
In case of PM Malfunction Alert, HBRT invokes PRD by setting bit OCC LFIR[stop_recovery_notify_prd] after collecting STOP Recovery FFDC. In response to FIR bit, PRD calls p9_pm_callout. It returns to PRD a bit vector which represent all the cores considered dead by PHYP due to PM malfunction. This commit accomplishes level2 implementation of p9_pm_callout. Key_Cronus_Test=PM_REGRESS HW-Image-Prereq: Ieb0bceeb141cc80b18f63b01e881e5ad3b50263d CQ: SW416531 Change-Id: I4b7c3e1e250fc779d5c1de2037131c62fba41e85 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/50008 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: Cronus HW CI <cronushw-ci+hostboot@us.ibm.com> Reviewed-by: AMIT J. TENDOLKAR <amit.tendolkar@in.ibm.com> Reviewed-by: RANGANATHPRASAD G. BRAHMASAMUDRA <prasadbgr@in.ibm.com> Reviewed-by: Gregory S. Still <stillgs@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/52537 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H')
-rw-r--r--src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H14
1 files changed, 9 insertions, 5 deletions
diff --git a/src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H b/src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H
index 7a625ce57..374370c3a 100644
--- a/src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H
+++ b/src/import/chips/p9/procedures/hwp/pm/p9_pm_callout.H
@@ -37,7 +37,7 @@
// *HWP HWP Owner : Greg Still <stillgs@us.ibm.com>
// *HWP FW Owner : Prem S Jha <premjha2@in.ibm.com>
// *HWP Team : PM
-// *HWP Level : 1
+// *HWP Level : 2
// *HWP Consumed by : HB
//----------------------------------------------------------------------------
@@ -68,7 +68,11 @@ struct StopErrLogSectn
enum RasAction
{
- PROC_CHIP_CALLOUT = 0,
+ NO_CALLOUT = 0,
+ FW_CALLOUT = 1,
+ CORE_CALLOUT = 2,
+ PROC_CHIP_CALLOUT = 3,
+ MEMORY_CALLOUT = 4,
};
// function pointer typedef definition for HWP call support
@@ -77,7 +81,7 @@ typedef fapi2::ReturnCode (*p9_pm_callout_FP_t) (
const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>& i_procChipTgt,
fapi2::buffer <uint32_t>& o_deadCores,
std::vector < StopErrLogSectn >& o_ffdcList,
- RasAction& i_rasAction );
+ RasAction& o_rasAction );
extern "C"
{
@@ -86,7 +90,7 @@ extern "C"
/// @param[in] i_procChipTgt fapi2 target for P9 chip.
/// @param[out] o_deadCores bit vector of dead cores which needs to be runtime deconfigured
/// @param[out] o_ffdcList points to a list of STOP FFDC summary sub-sections.
/// @param[in] i_rasAction RAS action specified for FW.
/// @return fapi2 return code.
/// @note caller is expected to pass an empty vector. HWP will
/// populate a vector with a list pointers to various parts of
@@ -102,6 +106,6 @@ extern "C"
const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>& i_procChipTgt,
fapi2::buffer <uint32_t>& o_deadCores,
std::vector < StopErrLogSectn >& o_ffdcList,
- RasAction& i_rasAction );
+ RasAction& o_rasAction );
}
#endif //__P9_PM_CALLOUT
OpenPOWER on IntegriCloud
@@ -86,7 +90,7 @@ extern "C"
/// @param[out] o_deadCores bit vector of dead cores which needs to be runtime deconfigured
/// @param[out] o_ffdcList points to a list of STOP FFDC summary sub-sections.
- /// @param[in] i_rasAction RAS action specified for FW.
+ /// @param[out] o_rasAction RAS action specified for FW.
/// @return fapi2 return code.
/// @note caller is expected to pass an empty vector. HWP will